@@ -55,8 +55,8 @@ def clamp(value, lower, upper):
 
 
 LIMIT_RANGE = {
-    "up": (1365, 2458),
-    "down": (1638, 2458),
+    "up": (1365, 2458),  # 40-120度
+    "down": (1638, 2458),  # 60-120度
     "left": (548, 2048),
     "right": (548, 2048),
 }
