@@ -166,3 +166,6 @@ class adapter_modbus_bit_t(IntEnum):
     ADAPTER_MODBUS_BIT_AUTO_SET_MID_DOWN_SERVO = auto()
     ADAPTER_MODBUS_BIT_AUTO_SET_MID_LEFT_SERVO = auto()
     ADAPTER_MODBUS_BIT_AUTO_SET_MID_RIGHT_SERVO = auto()
+
+    # /* 串口舵机动作标记 */
+    ADAPTER_MODBUS_BIT_SERVO_ACTION = auto()
